@@ -1,37 +1,35 @@
-from typing import Optional
+from typing import Optional, Union
 from pydantic import BaseModel
 
 from metafile_sdk.api.api_base import ApiBase
 
 
 class MetanetNodeInfo(BaseModel):
-    nodeTxId: Optional[str]
-    nodeAddress: Optional[str]
-    nodePublicKey: Optional[str]
-    parentTxId: Optional[str]
-    parentAddress: Optional[str]
-    parentPublicKey: Optional[str]
-    outputIndex: Optional[int]
-    blockHeight: Optional[int]
-    rootTxId: Optional[str]
-    rootAddress: Optional[str]
-    rootPublicKey: Optional[str]
-    timestamp: Optional[int]
-    isValid: Optional[bool]
-    reason: Optional[str]
+    txId: str
+    nodeId: str
+    metanetId: str
+    rootTxId: str
+    size: str
+    address: str
+    publicKey: str
+    parentTxId: str
+    metaIdTag: str
+    nodeName: str
+    blockHeight: str
+    metaBlockHeight: int
+    confirmState: bool
+    fee: str
+    timestamp: str
 
 
 class MetanetGetNode(BaseModel):
     code: int
-    msg: str
-    time: int
-    error: str
-    result: MetanetNodeInfo
+    data: MetanetNodeInfo
 
 
 class ShowmandbApi(ApiBase):
 
-    _metanet_getnode = '/v1/metanet/getNode/{}'
+    _metanet_getnode = '/aggregation/v2/app/meta/getMetaDataNode/{}'
 
     def __init__(self, base_url: str, headers):
         super().__init__(base_url, headers)
@@ -44,4 +42,5 @@ class ShowmandbApi(ApiBase):
     def metanet_getnode(self, txid):
         path = self._metanet_getnode.format(txid)
         data = self._get(path)
+        print(data)
         return MetanetGetNode(**data)
